@@ -12,11 +12,11 @@ PGObject::Simple - Minimalist stored procedure mapper based on LedgerSMB's DBObj
 
 =head1 VERSION
 
-Version 1.10.1
+Version 1.1
 
 =cut
 
-our $VERSION = '1.10.1';
+our $VERSION = '1.1';
 
 
 =head1 SYNOPSIS
@@ -102,10 +102,7 @@ sub new {
     my $ref = {};
     $ref->{$_} = $args{$_} for keys %args;
     bless ($ref, $self);
-    $ref->set_dbh($ref->{dbh});
-    $ref->_set_funcprefix($ref->{_funcprefix});
-    $ref->_set_funcschema($ref->{_funcschema});
-    $ref->_set_registry($ref->{_registry});
+    $ref->set_dbh($ref->{dbh}) if $ref->{dbh};
     return $ref;
 }
 
@@ -136,32 +133,6 @@ sub _set_funcprefix {
     $self->{_func_prefix} = $funcprefix;
 }
 
-=head2 _set_funcschema 
-
-This sets the default funcschema for future calls.  This is overwridden by 
-per-call arguments, (PGObject::Util::DBMethod provides for such overrides on a
-per-method basis).
-
-=cut
-
-sub _set_funcschema {
-    my ($self, $funcschema) = @_;
-    $self->{_func_schema} = $funcschema;
-}
-
-=head2 _set_registry
-
-This sets the registry for future calls.  The idea here is that this allows for
-application object model wrappers to set which registry they are using, both for
-predictability and ensuring that interoperability is possible.
-
-=cut
-
-sub _set_registry {
-    my ($self, $registry) = @_;
-    $self->{_registry} = $registry;
-}
-
 =head2 call_dbmethod
 
 Does a straight-forward mapping (as described below) to the stored procedure 
@@ -171,39 +142,35 @@ object property.  The $args{args} hashref can be used to override arguments by
 name.  Unknown properties are handled simply by passing a NULL in, so the
 stored procedures should be prepared to handle these.
 
-As with call_procedure below, this returns a single hashref when called in a
-scalar context, and a list of hashrefs when called in a list context.
-
 =cut
 
 sub call_dbmethod {
     my ($self) = shift @_;
     my %args = @_;
     croak 'No function name provided' unless $args{funcname};
-    if (eval { $self->isa(__PACKAGE__) } and ref $self){
-        $args{dbh} = $self->{_DBH} if $self->{_DBH} and !$args{dbh};
+    $args{dbh} = $self->{_DBH} if $self->{_DBH} and !$args{dbh};
 
-        $args{funcprefix} = $self->{_func_prefix} if !defined $args{funcprefix};
-        $args{funcschema} = $self->{_func_schema} if !defined $args{funcschema};
-    }
+    $args{funcprefix} = $self->{_func_prefix} if !defined $args{funcprefix};
     $args{funcprefix} ||= '';
     my $info = PGObject->function_info(%args);
 
-    my $arglist = [];
-    @{$arglist} = map {
-        my $argname = $_->{name};
-        my $db_arg;
-        $argname =~ s/^in_//;
-        $db_arg = $self->{$argname} if ref $self;
-        $db_arg = $args{args}->{$argname} if exists $args{args}->{$argname};
-        $db_arg;
-    } @{$info->{args}};
-    $args{args} = $arglist;
-
-    # The conditional return is necessary since the object may carry a registry
-    # --CT
-    return $self->call_procedure(%args) if ref $self;
-    return __PACKAGE__->call_procedure(%args);
+    my $dbargs = [];
+    for my $arg (@{$info->{args}}){
+        $arg->{name} =~ s/^in_//;
+        my $db_arg = $self->{$arg->{name}};
+        if ($args{args}->{$arg->{name}}){
+           $db_arg = $args{args}->{$arg->{name}};
+        }
+        if (eval {$db_arg->can('to_db')}){
+           $db_arg = $db_arg->to_db;
+        }
+        if ($arg->{type} eq 'bytea'){
+           $db_arg = { type => 'bytea', value => $db_arg};
+        }
+        push @$dbargs, $db_arg;
+    }
+    $args{args} = $dbargs;
+    return $self->call_procedure(%args);
 }
 
 =head2 call_procedure 
@@ -213,28 +180,18 @@ passes the currently attached db connection in.  We use the previously set
 funcprefix and dbh by default but other values can be passed in to override the
 default object's values.
 
-This returns a single hashref when called in a scalar context, and a list of 
-hashrefs when called in a list context.  When called in a scalar context it 
-simply returns the single first row returned.
-
 =cut
 
 sub call_procedure {
     my ($self) = shift @_;
     my %args = @_;
-    if (eval { $self->isa(__PACKAGE__) } and ref $self ){
-        $args{funcprefix} = $self->{_func_prefix} if !defined $args{funcprefix};
-        $args{funcschema} = $self->{_func_schema} if !defined $args{funcschema};
-        $args{registry} = $self->{_registry} if !defined $args{registry};
-
-        $args{dbh} = $self->{_DBH} if $self->{_DBH} and !$args{dbh};
-    }
+    $args{funcprefix} = $self->{_func_prefix} if !defined $args{funcprefix};
     $args{funcprefix} ||= '';
 
+    $args{dbh} = $self->{_DBH} if $self->{_DBH} and !$args{dbh};
+
     croak 'No DB handle provided' unless $args{dbh};
-    my @rows = PGObject->call_procedure(%args);
-    return shift @rows unless wantarray;
-    return @rows;
+    PGObject->call_procedure(%args);
 }
 
 =head1 WRITING CLASSES WITH PGObject::Simple
@@ -334,7 +291,7 @@ L<http://search.cpan.org/dist/PGObject-Simple/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2016 Chris Travers.
+Copyright 2013 Chris Travers.
 
 Redistribution and use in source and compiled forms with or without 
 modification, are permitted provided that the following conditions are met:
